# Install

```shell
> virtualenv venv
> source venv/bin/activate
> pip install -r requirements.txt -r requirements_darwin.txt  --target venv/lib/python2.7/site-packages/
> pip install .
> python generate.py --help
```

